@@ -78,7 +78,7 @@ module DBus
         n = n[elem]
       end
       if n.nil?
-        puts "Warning, unknown object #{path}"
+        puts "Warning, unknown object #{path}" if $DEBUG
       end
       n
     end
@@ -187,7 +187,7 @@ module DBus
       @object_root = Node.new("/")
     end
 
-    # Connect to the bus and initialize the connection by saying 'Hello'.
+    # Connect to the bus and initialize the connection.
     def connect
       parse_session_string
       if @type == "unix:abstract"
@@ -327,7 +327,7 @@ module DBus
         # introspect in synchronous !
         send_sync(m) do |rmsg|
           if rmsg.is_a?(Error)
-            raise rmsg 
+            raise rmsg
           else
             return rmsg.params[0]
           end
@@ -345,7 +345,6 @@ module DBus
       nil
     end
 
-    # FIXME: describe this
     # Issues a call to the org.freedesktop.DBus.Introspectable.Introspect method
     # _dest_ is the service and _path_ the object path you want to introspect
     # If a code block is given, the introspect call in asynchronous. If not
@@ -459,7 +458,6 @@ module DBus
           DBus::Message::METHOD_RETURN].include?(retm.message_type) and
           retm.reply_serial == m.serial
         retm = wait_for_message
-        raise retm if retm.is_a?(Error)
         process(retm)
       end
     end
@@ -483,7 +481,7 @@ module DBus
       self.proxy.AddMatch(mr.to_s)
     end
 
-    # Process a message _m) based on its type.
+    # Process a message _m_ based on its type.
     # method call:: FIXME...
     # method call return value:: FIXME...
     # signal:: FIXME...
@@ -494,7 +492,7 @@ module DBus
         raise InvalidPacketException if m.reply_serial == nil
         mcs = @method_call_replies[m.reply_serial]
         if not mcs
-          puts "no return code for #{mcs.inspect} (#{m.inspect})"
+          puts "no return code for #{mcs.inspect} (#{m.inspect})" if $DEBUG
         else
           if m.message_type == Message::ERROR
             mcs.call(Error.new(m))
@@ -506,7 +504,7 @@ module DBus
         end
       when DBus::Message::METHOD_CALL
         if m.path == "/org/freedesktop/DBus"
-          puts "Got method call on /org/freedesktop/DBus"
+          puts "Got method call on /org/freedesktop/DBus" if $DEBUG
         end
         # handle introspectable as an exception:
         if m.interface == "org.freedesktop.DBus.Introspectable" and
@@ -534,7 +532,7 @@ module DBus
           end
         end
       else
-        puts "Unknown message type: #{m.message_type}"
+        puts "Unknown message type: #{m.message_type}" if $DEBUG
       end
     end
 
@@ -574,7 +572,7 @@ module DBus
       m.member = "Hello"
       send_sync(m) do |rmsg|
         @unique_name = rmsg.destination
-        puts "Got hello reply. Our unique_name is #{@unique_name}"
+        puts "Got hello reply. Our unique_name is #{@unique_name}" if $DEBUG
       end
     end
 
@@ -669,7 +667,7 @@ module DBus
           b = @buses[socket]
           b.update_buffer
           while m = b.pop_message
-            b.process(m) 
+            b.process(m)
           end
         end
       end
